@@ -1,6 +1,7 @@
 {
 
-  package Your;    #our second schema
+  package    #hide
+    Your;    #our second schema
   use 5.010;
   use strict;
   use warnings;
@@ -8,10 +9,11 @@
   use base qw(DBIx::Simple::Class);
 
   sub dbix {
-  
+
     # Singleton DBIx::Simple instance
     state $DBIx;
-    return ($DBIx = $_[1] ? $_[1] : $DBIx) || Carp::croak('DBIx::Simple is not instantiated for schema "Your"');
+    return ($DBIx = $_[1] ? $_[1] : $DBIx)
+      || Carp::croak('DBIx::Simple is not instantiated for schema "Your"');
   }
 }
 1;
